#
# spec file for package pdf2djvu
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pdf2djvu
Version:        0.9.19
Release:        3.12
Summary:        PDF to DjVu Converter
License:        GPL-2.0-only
Group:          Productivity/Publishing/PDF
URL:            https://jwilk.net/software/pdf2djvu
Source0:        https://github.com/jwilk/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/jwilk/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  djvulibre
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(GraphicsMagick++)
BuildRequires:  pkgconfig(ddjvuapi) >= 3.5.25
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  pkgconfig(poppler) >= 0.62
BuildRequires:  pkgconfig(uuid)
Requires:       djvulibre

%description
pdf2djvu creates DjVu files from PDF files. It's able to extract:
graphics, text layer, hyperlinks, document outline (bookmarks) and
metadata (including XMP metadata).

%lang_package

%prep
%autosetup -p1

%build
%if 0%{?suse_version} < 1550
export CXXFLAGS="%{optflags} -std=c++17"
%endif
%configure
%make_build

%install
%make_install
%find_lang %{name} --with-man

%files
%license doc/COPYING
%doc doc/changelog doc/credits doc/djvudigital doc/README
%{_bindir}/%{name}
%{_mandir}/man?/*

%files lang -f %{name}.lang

%changelog
* Mon Jan  9 2023 pgajdos@suse.com
- enable GraphicsMagick again; GraphicsMagick will stay for the
  near future at least [bsc#1206620#c20]
* Wed Dec 21 2022 pgajdos@suse.com
- disable GraphicsMagick, it will be removed from Factory
* Fri Sep 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.9.19
  * Fix build failure with Poppler ≥ 22.03.
  * When converting PDF strings to UTF-8, keep non-characters
    intact.
  * Improve warning message for (unhandled) reset-form actions.
  * Improve handling of Poppler memory allocation failures.
  * Update the Polish translation.
  * Drop support for Poppler < 0.62.
  * Improve the configure script
  * Improve the test suite
- Drop patches, no longer needed:
  * 0001-pdf-backend-fix-compat-with-Poppler-22.02.patch
  * 0002-main-use-pdf-link-Destination-copy-constructor.patch
  * 0003-pdf-backend-fix-compat-with-Poppler-22.02.patch
  * 0004-pdf-backend-simplify-Poppler-22.03-compat-code.patch
* Thu Apr 14 2022 Max Lin <mlin@suse.com>
- Use C++17 for fix Leap build
* Wed Mar 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.9.18.2:
  * Document minimum required Exiv2 version.
  * Fix build failure with upcoming Exiv2 1.0.
  * Remove spurious zero-width spaces from the Ukrainian manual
    page.
  * Improve the test suite
- Add upstream changes:
  * 0001-pdf-backend-fix-compat-with-Poppler-22.02.patch
  * 0002-main-use-pdf-link-Destination-copy-constructor.patch
  * 0003-pdf-backend-fix-compat-with-Poppler-22.02.patch
  * 0004-pdf-backend-simplify-Poppler-22.03-compat-code.patch
* Sat Oct 23 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.9.18.1
  * Fix build failure with Poppler ≥ 21.10.
* Fri Jun 11 2021 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 0.9.18.
  * Fix configure check for Poppler ≥ 20.12.
  * Fix build failure with GCC 11.
  * Drop support for Python 2.6.
  * Fix typo in the Russian documentation.
- Drop pdf2djvu-fix-poppler-check.patch: fixed upstream.
* Fri Jan  8 2021 Atri Bhattacharya <badshah400@gmail.com>
- Add pdf2djvu-fix-poppler-check.patch: Check for poppler instead
  of poppler-splash, the latter of which is no longer installed by
  poppler >= 20.12 [gh#jwilk/pdf2djvu#144]; add BuildRequires:
  libtool, needed to rebuild configure script after applying
  patch.
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.9.17.1:
  * fixes
* Sat Apr  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Drop -lang Recommends: No longer needed, Supplements in place.
- Use modern macros.
* Wed Mar 11 2020 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 0.9.17.
  * Fix build failure with Poppler ≥ 0.86.
  * Drop support for Poppler < 0.35.
* Mon Feb 24 2020 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 0.9.16.
  * Fix build failure with Poppler ≥ 0.85.
- Disable tests: depend on Python2.
* Mon Dec 23 2019 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 0.9.15.
  * Fix build failure with Poppler ≥ 0.83.
* Mon Nov  4 2019 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 0.9.14.
  * Fix build failure with Poppler ≥ 0.82.
* Sun Jun 16 2019 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 0.9.13.
  * Fix build failure with Poppler ≥ 0.76.
  * Improve warning message for (unhandled) hide actions.
  * Improve the test suite:
    + Don't enforce the C locale.
    + Make it easy to pass arguments to nose.
  * Update the Polish translation.
  * Use HTTPS for exiv2.org URLs.
  * Update poppler-data URL.
  * Add support for heap profiling using gperftools.
- Correct description a bit.
* Sun Jan  6 2019 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 0.9.12.
  * Fix build failure with Poppler ≥ 0.72.
  * Improve the test suite.
  * Improve typography in the manual page.
- Changes in 0.9.11.
  * Fix build failure with Poppler ≥ 0.70.
  * Improve error handling.
  * Improve the build system.
  * Improve the test suite.
  * Improve documentation.
* Wed Oct 17 2018 lazy.kent@opensuse.org
- Update to 0.9.10.
  * Implement work-around for lack of thread-safety in the miniexp
    API in DjVuLibre < 3.5.26.
  * Drop support for DjVuLibre < 3.5.25.
  * Improve documentation:
    + Use HTTPS for www.openmp.org URLs.
    + Point to Python 2 documentation in the manual page.
    + Update the credits file to make it clear that the project is
    no longer being funded.
  * Improve the build system:
    + Add checks against BSD make. (Only GNU make is supported.).
    + Fix portability of the manpage building script.
    + Ignore the WINDRES variable on non-Windows systems.
  * Improve the test suite.
- BuildRequires: pkgconfig(ddjvuapi) >= 3.5.25.
* Thu Apr 19 2018 lazy.kent@opensuse.org
- Update to 0.9.9.
  * Fix build failure with Poppler ≥ 0.64.
  * Fix undefined behavior in the outline handling code.
* Fri Jan 19 2018 lazy.kent@opensuse.org
- Update to 0.9.8.
  * Make --help and --version print to stdout, not stderr.
  * Fix build failure with Poppler ≥ 0.62.
  * Drop support for Poppler < 0.24.
  * Use HTTPS for savannah.gnu.org and unicode.org URLs.
  * Improve documentation.
  * Improve the configure script.
  * Remove the install-poppler-h-files tool.
  * Improve the test suite.
- Add README to docs.
* Sun Sep 24 2017 zaitor@opensuse.org
- Update to version 0.9.7:
  * Fix build failure with Poppler ≥ 0.58.
  * Improve the build system: Fix non-portable sed(1) calls in the
    manpage translations makefile.
* Thu Aug 17 2017 lazy.kent@opensuse.org
- Update to 0.9.6.
  * Port the code to C++11.
    Incidentally, this fixes build failure with Poppler ≥ 0.57.
  * Fix GCC 8 warnings about catching polymorphic type by value.
  * Improve the test suite.
* Tue Jan  3 2017 lazy.kent@opensuse.org
- Update to 0.9.5.
  * Improve error handling:
    + Fix temporary files removal order.
    + Ignore duplicate page titles (with warning).
  * Fix creating bookmarks with more than 255 children. Regression
    introduced in 0.7.20.
  * Fix incorrect progress output in parallel mode.
  * Improve documentation:
    + Don't mention “--page-title-template=” as a way of disabling
    page titles. This works only if “--no-page-titles” works;
    there's no reason to prefer the former.
    + Update nose homepage URL.
    + Update OpenMP URLs.
    + Fix typos.
  * Improve the test suite.
  * Drop support for Poppler < 0.17.
  * Build with “-std=gnu++98”.
  * Build with “-Wempty-body”.
  * Build with “-Werror=misleading-indentation”.
  * Don't enable unknown warning options for clang.
  * Update German, Polish, Portuguese, Russian translations.
- Correct the source URLs.
* Thu Feb 25 2016 lazy.kent@opensuse.org
- Update to 0.9.4.
  * Standardize on American spelling in the manual page.
  * Document that bugs can be reported to the mailing list.
  * Fix build failure with GCC 6.
  * Improve warning message when a link with an unsupported action
    type is encountered.
  * Improve error handling in out-of-memory situations.
  * Use HTTPS for sourceforge.net and freedesktop.org URLs.
  * Improve the test suite.
  * Update Polish, German, Portuguese, Russian translations.
  * Update the French translation of the manual page.
* Tue Dec  1 2015 lazy.kent@opensuse.org
- Update to 0.9.3.
  * Fix rendering some vector elements that should go to the
    foreground layer. Regression introduced in 0.7.1.
  * Improve the test suite.
* Sun Oct 25 2015 lazy.kent@opensuse.org
- Update to 0.9.2.
  * Improve error handling.
    + Ignore document outline items with non-existent
    destinations.
  * Improve the test suite.
  * Update Polish, German, Portuguese, Russian translations.
* Wed Sep 30 2015 lazy.kent@opensuse.org
- Update to 0.9.1.
  * Fix detection of libraries needed for XMP support in the
    configure script.
  * Use DCE uuid_*() functions (instead of libuuid) if they are
    provided by libc.
  * Improve error handling.
- Changes in 0.9.
  * Add support for PDF page labels in page titles. Use labels as
    default page titles.
  * Add the “--no-page-title” option. Also, don't set page title if
    “--page-title-template” is empty.
  * Rename “--pageid-prefix” as “--page-id-prefix”.
  * Rename “--pageid-template” as “--page-id-template”.
  * Improve XMP support:
    + Use the Exiv2 library (instead of the GNOME XSLT library with
    hand-crafted XSL stylesheets).
    + Update the xmpMM:InstanceID property.
    + Update the xmpMM:DocumentID property.
    + Generate globally unique identifiers in the urn:uuid
    namespace.
    + Use correct timezone offset in xmp:MetadataDate.
  * Fix a few spelling mistakes in the manual page.
  * Fix support for files larger than 2GB on 32-bit systems.
  * Improve error handling.
  * Improve the test suite.
  * Update the Polish translation.
  * Disable building the Ukrainian manual page, which is not fully
    translated.
  * Update the Portuguese translation.
  * Update the German translation.
  * Update the French translation of the manual page.
  * Update the Russian translation.
- Changes in 0.8.2.
  * Fix file corruption for some documents with outline. Regression
    introduced in 0.7.20.
  * Improve thread-safety:
    + Make GraphicsMagick initialization thread-safe.
    + Rewrite the subprocess handling code to be thread-safe.
    Remove PStreams support.
  * Fix silencing djvuextract's stderr.
  * Use iconv() for converting from locale encoding to UTF-8.
  * Improve error handling.
  * Improve the test suite.
  * Update the Polish translation.
  * Update the Portuguese translation.
  * Update the German translation.
- Remove BuildRequires: pkgconfig(libxslt).
- Add BuildRequires: pkgconfig(exiv2), pkgconfig(uuid).
* Mon Aug 17 2015 lazy.kent@opensuse.org
- Update to 0.8.1.
  * Fix “--fg-colors=N” when GraphicsMagick was compiled with
    QuantumDepth > 8.
  * Report GraphicsMagick's QuantumDepth in “--version”.
  * Build with “-Werror=narrowing”.
  * Document what software is required to run the tests.
  * Improve the test suite.
- Correct: BuildRequires: pkgconfig(ddjvuapi) >= 3.5.21;
  pkgconfig(poppler) >= 0.11.1.
* Sun Aug  9 2015 lazy.kent@opensuse.org
- Update to 0.8.
  * Don't hardcode the Python interpreter path in script shebangs;
    use “#!/usr/bin/env python” instead.
  * Don't silently ignore --loss-level when used without
  - -monochrome.
  * Add sanity check that output file is distinct from all input
    files.
  * Apply NFKC normalization on characters from the Alphabetic
    Presentation Forms block (U+FB00–U+FB4F), even when --no-nfkc
    were specified. This is what Poppler (≥ 0.19) does by default.
  * Fail early if duplicate page numbers were specified in
  - p/--pages.
  * Fail early on duplicate page identifiers and duplicate page
    titles.
  * Make --help and --version return with exit code 0.
  * Improve the configure script:
    + Check if Poppler xpdf headers exist.
    + Add option for disabling PStreams (--without-pstreams).
  * Change the order libraries on linker command line. Move
    libraries provided by the LIBS configure variable to the end.
  * Use the reentrant S-expression output API when it's available
    (DjVuLibre >= 3.5.25).
  * Improve error handling.
  * Improve the test suite.
  * Improve documentation:
    + Simplify documentation about build dependencies.
    + Document that pkg-config is required for building.
    + Update poppler-data download URL.
  * Update Polish, Portuguese, German, Russian translations and the
    French translation of the manual page.
* Mon May 11 2015 lazy.kent@opensuse.org
- Update to 0.7.21.
  * Fix insecure use of /tmp when executing c44(1).
* Fri May  8 2015 lazy.kent@opensuse.org
- Update to 0.7.20.
  * Don't use djvused for setting document outline.
  * Test suite: automatically skip tests that require features that
    were not enabled at build time.
  * Improve reporting of versions of the libraries in --version and
    XMP metadata.
  * Update the homepage URL and the bug tracker URLs, in
    documentation and code.
  * Update Portuguese, Russian, German and Ukrainian translations.
- Add for tests BuildRequires: python-imaging.
- Correct the URL tag.
* Thu Mar 12 2015 lazy.kent@opensuse.org
- Add %%check section to run 'make test'.
- Update the keyring file.
* Mon Mar  9 2015 p.drouand@gmail.com
- Update to version 0.7.19
  * Fix build failure with Poppler ≥ 0.31.
    https://code.google.com/p/pdf2djvu/issues/detail?id=99
- Remove gpg-offline usage; OBS handles sources verification
- Update download Url
- Do not use %%doc with manpages; it's redundant
- Changes in 0.7.18.
  * Make the xml2c script more portable.
  * In C++11 mode, use “decltype” instead of “typeof”.
  * Fix build failure with libc++ in C++98 mode.
  * Use the standard AC_OPENMP macro in the configure script
    (instead of 3rd-party AX_OPENMP).
  * Use HTTPS URLs when they are available, in documentation and
    code.
  * Add Portuguese translation; add French translation of the
    manual page; fix capitalization error in the German manual
    page.
  * Drop support for Poppler < 0.11.1.
  * Improve error handling.
* Fri May 31 2013 lazy.kent@opensuse.org
- Update to 0.7.17.
  * Fix build failure with Poppler ≥ 0.23.
- Changes in 0.7.16.
  * Fix build failure with Poppler ≥ 0.21.1.
- Drop pdf2djvu-poppler.patch (fixed upstream).
- Verify GPG signature.
* Tue Nov 13 2012 idonmez@suse.com
- add pdf2djvu-poppler.patch to fix compile with new poppler
* Sun Oct  7 2012 lazy.kent@opensuse.org
- Update to 0.7.15.
  + Fix build failure with Poppler ≥ 0.21.
* Wed Sep 19 2012 lazy.kent@opensuse.org
- Update to 0.7.14.
  + Ignore links with no action. (Previously such links would cause
    segfault).
  + Update German, Russian, Ukrainian translations.
* Mon Jun  4 2012 lazy.kent@opensuse.org
- Update to 0.7.13.
  + Fix build failure with Poppler ≥ 0.19.
  + Update German, Russian, Ukrainian translations.
  + Add Ukrainian translation of the manual page.
- Disable tests (Python problem).
* Tue Feb 28 2012 lazy.kent@opensuse.org
- Split off language package.
- Use pkgconfig(*) build dependencies.
* Sun Jan 22 2012 lazy.kent@opensuse.org
- Update to 0.7.12
  + Fix resolution detection.
  + Add Ukrainian translation.
* Thu Oct  6 2011 lazy.kent@opensuse.org
- Update to 0.7.11
  + Fix build failure with Poppler >= 0.17.
- Removed pdf2djvu-poppler-0.18.patch (fixed upstream).
- Removed obsolete "clean" section.
* Tue Sep 20 2011 vuntz@opensuse.org
- Add pdf2djvu-poppler-0.18.patch: fix build with poppler
  0.17/0.18.
* Sat Aug 20 2011 lazy.kent@opensuse.org
- Update to 0.7.10
  + Fix the --monochrome option.
  + Fix crash with --no-metadata.
* Thu Aug 18 2011 lazy.kent@opensuse.org
- Update to 0.7.9
  + Add Russian translation.
* Mon Jul 25 2011 lazy.kent@opensuse.org
- Update to 0.7.8
  + Add support for merging multiple PDFs into a single DjVu file.
  + Add German translation.
* Fri May 27 2011 lazy.kent@opensuse.org
- Build requires ghostscript-fonts-std to run tests correctly
- Use full URL for source
* Wed Mar 30 2011 lazy.kent@opensuse.org
- Update to 0.7.7
  + Fix build failure with GCC 4.6.
  + Make it possible to control how work is distributed between
    threads with the OMP_SCHEDULE variable.
* Sat Feb 19 2011 lazy.kent@opensuse.org
- Update to 0.7.6
- Man pages marked as docs
* Fri Jan 21 2011 lazy.kent@opensuse.org
- Don't make test in SLE
* Thu Jan 20 2011 lazy.kent@opensuse.org
- Update to 0.7.5
  + Document the use of TMPDIR environment variable.
- Make tests
- Added COPYING
* Sun Jun 13 2010 lazy.kent.suse@gmail.com
- Update to 0.7.4
  + Fix handling of the --pages option.
  + Fix build failure with GCC 4.2.
  + Make messages about missing features a bit more informative.
- Dropped obsolete patch
* Sat Jun 12 2010 lazy.kent.suse@gmail.com
- Fixed handling of the --pages option
* Mon May 24 2010 lazy.kent.suse@gmail.com
- Update to 0.7.3
  + Fix handling of the --indirect option.
* Sun May  2 2010 lazy.kent.suse@gmail.com
- Update to 0.7.2
  + Add the --fg-colors=black option.
  + Fix broken output with --fg-colors=web.
  + Fix crash with GraphicMagick ≥ 1.3.8.
  + Override number of threads set by GraphicsMagick.
- Added some docs
* Tue Apr 20 2010 lazy.kent.suse@gmail.com
- Update to 0.7.1
  + Speed up converting pages for which no foreground were
    detected.
* Sun Feb 28 2010 lazy.kent.suse@gmail.com
- Update to 0.7.0
  + Add support for parallel page rendering: options -j/--jobs.
* Fri Jan 15 2010 lazy.kent.suse@gmail.com
- Update to 0.6.2
  + Fix build failure without PStreams.
* Fri Jan 15 2010 lazy.kent.suse@gmail.com
- Update to 0.6.1
  + Add the --text-filter option.
- Added libGraphicsMagick++-devel, libxslt-devel and pstreams-devel
  to BuildRequires
* Fri Oct  2 2009 lazy.kent.suse@gmail.com
- Update to 0.6.0
  + New regression tests.
  + Add support for correcting XMP metadata.
  + Fix resolution detection (poppler ≥ 0.11.1 only).
* Thu Jul 30 2009 lazy.kent.suse@gmail.com
- Update to 0.5.11
  + Document how to deal with CJK PDFs.
* Sat Jul 11 2009 lazy.kent.suse@gmail.com
- Update to 0.5.10
  + Add Polish translation of the manual page.
* Tue Jun 30 2009 lazy.kent.suse@gmail.com
- Added djvulibre to Requires
* Thu Jun 18 2009 lazy.kent.suse@gmail.com
- Update to 0.5.9
  + Add Polish translation
* Mon Jun  1 2009 lazy.kent.suse@gmail.com
- Spec-file cleanup
* Sat May 16 2009 lazy.kent.suse@gmail.com
- Update to 0.5.8
  + Fix some rounding bugs.
* Thu May  7 2009 lazy.kent.suse@gmail.com
- Update to 0.5.7
  + Add the --guess-dpi option.
* Tue May  5 2009 lazy.kent.suse@gmail.com
- Update to 0.5.6
  + New default quantization algorithm.
  + Fix some character encoding issues.
  + Stricter requirements for pageid names.
  + Lift a limitation on number of pages in a bundled multi-page
    document.
* Sun May  3 2009 lazy.kent.suse@gmail.com
- Update to 0.5.5
  + Add the --pageid-template option.
  + Add the --page-title-template option.
  + Don't allow duplicate page identifies nor duplicate page
    titles.
  + More robust UTF-16 to UTF-8 conversion.
* Wed Apr 15 2009 lazy.kent.suse@gmail.com
- Update to 0.5.4
  + Add the --crop-text option.
* Wed Apr 15 2009 lazy.kent.suse@gmail.com
- Initial package created - 0.5.3
